module FrontMan
  module ImagesHelper
    def sprite_tag(filename, options = {})
      content_tag :svg, options do
        tag :use, 'xlink:href' => "##{filename}"
      end
    end

    def inline_svg(filename)
      case FrontMan.framework
      when :rails
        file_path = "app/assets/images/#{filename}"
      when :middleman
        file_path = sitemap.find_resource_by_path(image_path('icons.svg'))
          .source_file
      end

      file_contents = File.read(file_path)
      content_tag :div, file_contents.html_safe, class: 'u-is-hidden'
    end

    def image_set_tag(filename, options = {})
      srcset = options[:srcset]
      if srcset.present?
        srcset = srcset.map { |src, size| "#{image_path(src)} #{size}" }
        srcset = srcset.join(', ')

        if options[:class].present? && options[:class].match(/\blazyload\b/)
          options = options.dup
          options.delete(:srcset)
          src = options[:src] || image_path(filename)
          options.delete(:src)
          options[:data] ||= {}
          options[:data] = { sizes: 'auto', src: src, srcset: srcset }
            .merge(options[:data])

          return no_src_image_tag(filename, options)
        else
          options[:srcset] = srcset
        end
      end

      image_tag(filename, options)
    end

    private

      # extracted and modified from
      # https://github.com/rails/rails/blob/878e42916db8a18f61333f315907480d7c48c040/actionview/lib/action_view/helpers/asset_tag_helper.rb#L208
      def no_src_image_tag(source, options)
        options = options.symbolize_keys

        src = path_to_image(source)

        unless src =~ /^(?:cid|data):/ || src.blank?
          options[:alt] = options.fetch(:alt){ image_alt(src) }
        end

        options[:width], options[:height] = extract_dimensions(options.delete(:size)) if options[:size]
        tag("img", options)
      end
  end
end
